==> ceph_17.2.9.orig.tar.xz: ceph-17.2.9/src/boost/libs/interprocess/test/recursive_mutex_test.cpp <==
//////////////////////////////////////////////////////////////////////////////
//
// (C) Copyright Ion Gaztanaga 2004-2012. Distributed under the Boost
// Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
//
// See http://www.boost.org/libs/interprocess for documentation.
//
//////////////////////////////////////////////////////////////////////////////

#include <boost/interprocess/detail/workaround.hpp>
#if defined(BOOST_INTERPROCESS_WINDOWS)
#include <boost/interprocess/sync/windows/recursive_mutex.hpp>
#include <boost/interprocess/sync/spin/recursive_mutex.hpp>
#endif
#include <boost/interprocess/sync/interprocess_recursive_mutex.hpp>
#include <boost/interprocess/sync/scoped_lock.hpp>
#include "mutex_test_template.hpp"

int main ()
{
   using namespace boost::interprocess;
   #if defined(BOOST_INTERPROCESS_WINDOWS)
      //
      test::test_all_lock<ipcdetail::windows_recursive_mutex>();
      test::test_all_mutex<ipcdetail::windows_recursive_mutex>();
      test::test_all_recursive_lock<ipcdetail::windows_recursive_mutex>();
      //
      test::test_all_lock<ipcdetail::spin_recursive_mutex>();
      test::test_all_mutex<ipcdetail::spin_recursive_mutex>();
      test::test_all_recursive_lock<ipcdetail::spin_recursive_mutex>();
   #endif
   //
   test::test_all_lock<interprocess_recursive_mutex>();
   test::test_all_mutex<interprocess_recursive_mutex>();
   test::test_all_recursive_lock<interprocess_recursive_mutex>();

   return 0;
}

==> ceph_19.2.0.orig.tar.xz: ceph-19.2.0/src/boost/libs/interprocess/test/recursive_mutex_test.cpp <==
//////////////////////////////////////////////////////////////////////////////
//
// (C) Copyright Ion Gaztanaga 2004-2012. Distributed under the Boost
// Software License, Version 1.0. (See accompanying file
// LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
//
// See http://www.boost.org/libs/interprocess for documentation.
//
//////////////////////////////////////////////////////////////////////////////

#include <boost/interprocess/detail/workaround.hpp>
#if defined(BOOST_INTERPROCESS_WINDOWS)
#include <boost/interprocess/sync/windows/recursive_mutex.hpp>
#include <boost/interprocess/sync/spin/recursive_mutex.hpp>
#endif
#include <boost/interprocess/sync/interprocess_recursive_mutex.hpp>
#include <boost/interprocess/sync/scoped_lock.hpp>
#include "mutex_test_template.hpp"

int main ()
{
   using namespace boost::interprocess;
   #if defined(BOOST_INTERPROCESS_WINDOWS)
      //
      test::test_all_lock<ipcdetail::winapi_recursive_mutex>();
      test::test_all_mutex<ipcdetail::winapi_recursive_mutex>();
      test::test_all_recursive_lock<ipcdetail::winapi_recursive_mutex>();
      //
      test::test_all_lock<ipcdetail::spin_recursive_mutex>();
      test::test_all_mutex<ipcdetail::spin_recursive_mutex>();
      test::test_all_recursive_lock<ipcdetail::spin_recursive_mutex>();
   #endif
   //
   test::test_all_lock<interprocess_recursive_mutex>();
   test::test_all_mutex<interprocess_recursive_mutex>();
   test::test_all_recursive_lock<interprocess_recursive_mutex>();

   return 0;
}
